xlsx_parts = {}

xlsx_parts[
    "xl/drawings/drawing.xml(png)"
] = """
 <xdr:oneCellAnchor>
    <xdr:from>
        <xdr:col>%(_col)s</xdr:col>
        <xdr:colOff>0</xdr:colOff>
        <xdr:row>%(_row)s</xdr:row>
        <xdr:rowOff>0</xdr:rowOff>
    </xdr:from>
    <xdr:ext cx="%(_width)s" cy="%(_height)s"/>
    <xdr:pic>
        <xdr:blipFill>
            <a:blip r:embed="rId%(_id)s"/>
        </xdr:blipFill>
        <xdr:spPr bwMode="auto">
            <a:xfrm>
                <a:off x="3030990" y="328576"/>
                <a:ext cx="996723" cy="491254"/>
            </a:xfrm>
            <a:prstGeom prst="rect">
                <a:avLst/>
            </a:prstGeom>
            <a:noFill/>
            <a:ln w="9525">
                <a:noFill/>
                <a:miter lim="800000"/>
                <a:headEnd/>
                <a:tailEnd/>
            </a:ln>
        </xdr:spPr>
    </xdr:pic>
 </xdr:oneCellAnchor>"""


xlsx_parts[
    "xl/drawings/drawing.xml"
] = """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
    <xdr:wsDr xmlns:xdr="http://schemas.openxmlformats.org/drawingml/2006/spreadsheetDrawing"
            xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main"
            xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships">
            %s
    </xdr:wsDr>"""
xlsx_parts[
    "xl/drawings/_rels/drawing.xml.rels"
] = """<?xml version="1.0" encoding="UTF-8"?>
    <Relationships xmlns="http://schemas.openxmlformats.org/package/2006/relationships">
        %s
    </Relationships>
    """
xlsx_parts[
    "xl/worksheets/sheet.xml"
] = """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<worksheet xmlns="http://schemas.openxmlformats.org/spreadsheetml/2006/main"
    xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships">

%s

    <sheetData>

%s

    </sheetData>

%s

%s

%s

</worksheet>"""
xlsx_parts[
    "xl/worksheets/_rels/sheet.xml.rels"
] = """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
        <Relationships xmlns="http://schemas.openxmlformats.org/package/2006/relationships">
        <Relationship Id="rId1"
            Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/drawing"
            Target="../drawings/drawing%s.xml"/>
        </Relationships>"""
xlsx_parts[
    "xl/workbook.xml"
] = """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
    <workbook
        xmlns="http://schemas.openxmlformats.org/spreadsheetml/2006/main"
        xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships">
        <sheets>
            %s
        </sheets>
        <calcPr calcId="125725" calcOnSave="0"/>
    </workbook>"""
xlsx_parts[
    "xl/styles.xml"
] = """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
            <styleSheet xmlns="http://schemas.openxmlformats.org/spreadsheetml/2006/main">
                %(fonts)s
                <fills count="1">
                    <fill>
                        <patternFill patternType="none"/>
                    </fill>
                </fills>
                %(borders)s
                <cellStyleXfs count="1">
                    <xf numFmtId="0" fontId="0" fillId="0" borderId="0"/>
                </cellStyleXfs>
                %(cellXfs)s
                <cellStyles count="1">
                    <cellStyle name="20%% - Q1" xfId="0" builtinId="30" customBuiltin="1"/>
                </cellStyles>
                <dxfs count="0"/>
                <tableStyles count="0"
                    defaultTableStyle="TableStyleMedium9"
                    defaultPivotStyle="PivotStyleLight16"/>
            </styleSheet>"""
xlsx_parts[
    "xl/sharedStrings.xml"
] = """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
                    <sst xmlns="http://schemas.openxmlformats.org/spreadsheetml/2006/main"
                        count="%s"
                        uniqueCount="%s">
                        %s
                    </sst>"""
xlsx_parts[
    "workbook.xml"
] = """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
    <workbook
        xmlns="http://schemas.openxmlformats.org/spreadsheetml/2006/main"
        xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships">
        <sheets>
            <!-- <sheet name="Sheet1" sheetId="1" r:id="rId1"/>     -->
        </sheets>
        <calcPr calcId="125725" calcOnSave="0"/>
    </workbook>"""
xlsx_parts[
    "xl/_rels/workbook.xml.rels-line"
] = """<Relationship Id="rId%s"
        Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/worksheet"
        Target="worksheets/sheet%s.xml"/>"""
xlsx_parts[
    "xl/_rels/workbook.xml.rels"
] = """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
                        <Relationships xmlns="http://schemas.openxmlformats.org/package/2006/relationships">
                        <Relationship Id="rId3"
                            Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/styles"
                            Target="styles.xml"/>
                        <Relationship Id="rId4"
                            Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/sharedStrings"
                            Target="sharedStrings.xml"/>
                        %s
                        </Relationships>"""
xlsx_parts[
    "_rels/.rels"
] = """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
                <Relationships xmlns="http://schemas.openxmlformats.org/package/2006/relationships">
                    <Relationship Id="rId1"
                    Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument"
                    Target="xl/workbook.xml"/>
                </Relationships>"""
xlsx_parts[
    "[Content_Types].xml"
] = """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
                <Types xmlns="http://schemas.openxmlformats.org/package/2006/content-types">
                <Default Extension="png" ContentType="image/png"/>
                <Default Extension="jpg" ContentType="image/jpg"/>
                <Default Extension="rels"
                    ContentType="application/vnd.openxmlformats-package.relationships+xml"/>
                <Default Extension="xml" ContentType="application/xml"/>
                <Override PartName="/xl/styles.xml"
                    ContentType="application/vnd.openxmlformats-officedocument.spreadsheetml.styles+xml"/>
                <Override PartName="/xl/workbook.xml"
                    ContentType="application/vnd.openxmlformats-officedocument.spreadsheetml.sheet.main+xml"/>
                <Override PartName="/xl/sharedStrings.xml"
                    ContentType="application/vnd.openxmlformats-officedocument.spreadsheetml.sharedStrings+xml"/>
                %s
                </Types>"""
xlsx_parts[
    "images"
] = """<Relationship Id="rId%s"
    Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/image"
    Target="../media/image%s.png"/>"""
xlsx_parts[
    "wb_content_types_sheet"
] = """<Override PartName="/xl/worksheets/sheet%s.xml"
            ContentType="application/vnd.openxmlformats-officedocument.spreadsheetml.worksheet+xml"/>"""
xlsx_parts[
    "wb_content_types_image"
] = """<Override PartName="/xl/drawings/drawing%s.xml"
        ContentType="application/vnd.openxmlformats-officedocument.drawing+xml"/>
"""



docx_parts={}
docx_parts['doc_start'] = """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<w:document 
    xmlns:wne="http://schemas.microsoft.com/office/word/2006/wordml" 
    xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main" 
    xmlns:w10="urn:schemas-microsoft-com:office:word" 
    xmlns:wp="http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing" 
    xmlns:v="urn:schemas-microsoft-com:vml" 
    xmlns:m="http://schemas.openxmlformats.org/officeDocument/2006/math" 
    xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships" 
    xmlns:o="urn:schemas-microsoft-com:office:office" 
    xmlns:ve="http://schemas.openxmlformats.org/markup-compatibility/2006">
<w:body>

"""
docx_parts['image'] = """
    <w:r>
    <w:drawing>
        <wp:anchor
            behindDoc="1"
            distT="0"
            distB="0"
            distL="0"
            distR="0"
            simplePos="0"
            locked="0"
            layoutInCell="0"
            allowOverlap="1"
            relativeHeight="2"
            >
            <wp:simplePos   x="0"
                            y="0"/>
            <wp:positionH relativeFrom="column">
                <wp:align>left</wp:align>
            </wp:positionH>
            <wp:positionV relativeFrom="paragraph">
                <wp:posOffset>0</wp:posOffset>
            </wp:positionV>

            <wp:effectExtent
                    l="0"
                    t="0"
                    r="0"
                    b="0"/>
            <wp:wrapNone/>
            
            <wp:cNvGraphicFramePr>
                <a:graphicFrameLocks xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main"
                    noChangeAspect="1"/>
            </wp:cNvGraphicFramePr>
            <a:graphic xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main">
                <a:graphicData uri="http://schemas.openxmlformats.org/drawingml/2006/picture">
                    <pic:pic xmlns:pic="http://schemas.openxmlformats.org/drawingml/2006/picture">
                        <pic:blipFill>
                            <a:blip r:embed="rId%(imageIndex)s"/>
                            <a:stretch>
                                <a:fillRect/>
                            </a:stretch>
                        </pic:blipFill>
                        <pic:spPr bwMode="auto">
                            <a:xfrm>
                                <a:off
                                    x="0"
                                    y="0"/>
                                <a:ext
                                    cx="%(width)s"
                                    cy="%(height)s"/>
                            </a:xfrm>
                            <a:prstGeom prst="rect">
                                <a:avLst/>
                            </a:prstGeom>
                        </pic:spPr>
                    </pic:pic>
                </a:graphicData>
            </a:graphic>
        </wp:anchor>
    </w:drawing>
    </w:r>
    """
docx_parts['rels'] = """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
    <Relationships xmlns="http://schemas.openxmlformats.org/package/2006/relationships">
    <Relationship Id="rId1" Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument" Target="word/document.xml"/>
    </Relationships>"""
docx_parts['content_type'] = """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
    <Types xmlns="http://schemas.openxmlformats.org/package/2006/content-types">
    <Default Extension="jpg" ContentType="image/jpg"/>
    <Default Extension="rels" ContentType="application/vnd.openxmlformats-package.relationships+xml"/>
    <Override PartName="/word/document.xml" ContentType="application/vnd.openxmlformats-officedocument.wordprocessingml.document.main+xml"/>
    </Types>"""
docx_parts['word_rels'] = """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
    <Relationships xmlns="http://schemas.openxmlformats.org/package/2006/relationships">
    %s
    </Relationships>"""
docx_parts['images'] = """<Relationship Id="rId%s" 
    Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/image"
    Target="media/image%s.png"/>"""



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['q2report', 'q2report.q2engine', 'q2report.q2printer']

package_data = \
{'': ['*']}

install_requires = \
['pillow>=9.4.0,<10.0.0']

setup_kwargs = {
    'name': 'q2report',
    'version': '0.1.20',
    'description': '',
    'long_description': '# The light Python report builder.\nConverts data into formatted text (**HTML**, **DOCX**, **XLSX**):\n```python\ndata = {\'data_source1\':[{\'col1\': \'value row1\', ....}, ...],\n        \'data_source2\':[{\'col_1\': \'valie_row1\', ....}, ...],\n        }\n```\nAvailable formatting (styling options):\n```json  \n"style": {\n    "font-family": "Arial",\n    "font-size": "10pt",\n    "font-weight": "normal",\n    "border-width": "0 0 0 0",\n    "padding": "0.05cm 0.05cm 0.05cm 0.05cm",\n    "text-align": "left",\n    "vertical-align": "top"\n  }\n\n```\n## Concept\nThe report definition consists of sections (Report, Pages, Columns, Rows, Cells).  \nEach section inherits style from previous and may override some styling options.  \n*see examples in folder **test_data***\n```python\nReport:  # contains basic style\n    Pages:  # page & margins sizes\n        Columns:  # columns widths - exact, % or autowidth\n            Rows:  # rows heights - auto, exact, min or max\n                   # can be linked to data and then have header, footer and grouping subsections\n                   # \n                Cells  # contains simple text and data links - {col1}\n                       # and aggregate functions - {sum:coll}\n                       # support html formatting with <b> <i> <u> <br>\n                       # cells may be merged (span)\n            Rows:\n                Cells\n            ....\n        Columns:\n            ....\n    Pages:\n        ....\n    ....\n```',
    'author': 'Andrei Puchko',
    'author_email': 'andrei.puchko@gmx.de',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
